const { resolvePackage } = require('./common')

/**
 * 检查是否安装less
 * @returns {boolean}
 */
function detectLess() {
  try {
    resolvePackage('less')
    return true
  } catch (e) {
    return false
  }
}

/**
 * 检查是否安装less-loader
 * @returns {boolean}
 */
function detectLessLoader() {
  try {
    resolvePackage('less-loader')
    return true
  } catch (e) {
    return false
  }
}

let pkgRoot
let mainPath

/**
 * 检查是否安装icefox等依赖
 * 如果没有安装，则提醒安装，并退出程序。
 */
function detectDependencies() {
  const dependencies = []
  if (!detectLess()) {
    dependencies.push('less')
  }
  if (!detectLessLoader()) {
    dependencies.push('less-loader')
  }
  try {
    ;({ main: mainPath, path: pkgRoot } = resolvePackage('icefox'))
  } catch (e) {
    dependencies.unshift('icefox')
    logger.error(`\nSome dependencies were not found. Please install it first.`)
    logger.logWithBoxen(`npm install ${dependencies.join(' ')}`)
    process.exit(2)
  }
}

// 检测依赖安装情况
detectDependencies()

const path = require('path')
const lib = 'lib'

module.exports = exports = {
  // 包根目录
  root: pkgRoot,
  // 包入口文件
  main: mainPath,
  // 应用的包目录
  lib: path.join(pkgRoot, 'lib'),
  // 代码目录：app
  app: path.join(pkgRoot, lib, 'app'),
  // 代码目录：plugins
  plugins: path.join(pkgRoot, lib, 'plugins'),
  // 代码目录：components
  components: path.join(pkgRoot, lib, 'components'),
  // 静态资源目录
  assets: path.join(pkgRoot, lib, 'assets'),
}
